# Welcome to GAICo
GAICo Quickstart Demonstration
{{ readme("BADGES") }} {{ readme("TAGLINE") }} {{ readme("DESCRIPTION_FULL") }}
![GAICo Overview](https://raw.githubusercontent.com/ai4society/GenAIResultsComparator/refs/heads/main/gaico.drawio.png){ width="500" }
Overview of the workflow supported by the GAICo library
{{ readme("FEATURES_SECTION") }} {{ readme("INSTALLATION_SECTION") }} {{ readme("CITATION_SECTION") }} {{ readme("ACKNOWLEDGMENTS_SECTION") }} {{ readme("CONTACT_SECTION") }}